@@ -31,7 +31,7 @@ def get_cache_directory(level=logging.DEBUG):
     logger.addHandler(logging.StreamHandler())
 
     if platform.system().lower() == "windows":
-        return os.path.expandvars(%localappdata%)
+        return os.path.expandvars(R"%localappdata%")
     elif platform.system().lower() == "linux":
         return "~/.cache"
     elif platform.system().lower() == "darwin":
